     /**
  * @file pwm_driver_pic.c
  * @brief This module contains the implementation of the PWM driver hardware
  * function.

  * @author Stefan Popovic
  *
  * @date 7/12/2016
  *
  * @version 0.1a
  *
  * @copyright GNU Public License
  *
  * Test configuration:
  *
  * MCU: PIC18F45K22
  * Dev.Board: EasyPIC v7 Connectivity
  * Oscillator: internal 8.0000 MHz RC
  * Ext. Modules: PWM driver click Board
  * SW: MikroC PRO for PIC v6.6.3

  * NOTES:
    - Place PWM driver click board on mikroBUS slot 2
    - Turn on Lcd backlight on SW4.6
    - Turn ON the PORTC LEDs at SW3.3
    - To simulate analog input on ADC channel 1, use on-board potentiometer P1
      by connecting jumper (J15) (board specific) to RA1 (ADC channel 1 input)
    - Put button jumper (J17) into VCC position
    - PWM: RC1 8 - bit
    - ADC: RA1 10 - bit
    - Output LED: RC1
  /**************************************************************************
  * Module Preprocessor Constants
  **************************************************************************/

  /**************************************************************************
  * Module Preprocessor Macros
  **************************************************************************/


  /**************************************************************************
  * Module Typedefs
  **************************************************************************/
  
  /**************************************************************************
  * Includes
  **************************************************************************/
  #include <built_in.h>
  #include <stdint.h>
  /**************************************************************************
  * Module Variable Definitions
  **************************************************************************/
  // Lcd module connections
  sbit LCD_RS at LATB4_bit;
  sbit LCD_EN at LATB5_bit;
  sbit LCD_D4 at LATB0_bit;
  sbit LCD_D5 at LATB1_bit;
  sbit LCD_D6 at LATB2_bit;
  sbit LCD_D7 at LATB3_bit;

  sbit LCD_RS_Direction at TRISB4_bit;
  sbit LCD_EN_Direction at TRISB5_bit;
  sbit LCD_D4_Direction at TRISB0_bit;
  sbit LCD_D5_Direction at TRISB1_bit;
  sbit LCD_D6_Direction at TRISB2_bit;
  sbit LCD_D7_Direction at TRISB3_bit;
  // End Lcd module connections

  uint16_t current_duty;
  uint16_t adc_rd;
  char txt1[] = "PWM driver click";
  char txt2[] = "PWM Duty";
  char txt3[] = "%";
  char txt[5];

  void MCU_Init() 
  {
    ANSELA = 0x02;                      // Configure AN pins as digital
    ANSELD = 0;
    ANSELB = 0;
    ANSELC = 0;
    TRISA = 0x02;                       // designate PORTA pins as output, except pin 1
    TRISC = 0;                          // designate PORTC pins as output
    LATC  = 0;                          // set PORTC to 0
    PWM2_Init( 5000 );                  // Initialize PWM2 module at 5KHz
  }

  void Lcd_Display()
  {
    Lcd_Cmd(_LCD_CLEAR);                // Clear display
    Lcd_Cmd(_LCD_CURSOR_OFF);           // Cursor off
    Lcd_Out(1, 1, txt1);                // Write text in first row
    Lcd_Out(2, 1, txt2);                // Write text in second row
    Lcd_Out(2, 16, txt3);               // Write text in second row
  }
  void main()
  {
    MCU_Init();                         // Configure PORTB pins as digital
    Lcd_Init();                         // Initialize Lcd
    Lcd_Display();                      // Display text
    current_duty  = 0;
    PWM2_Start();
    PWM2_Set_Duty(current_duty);

    while ( 1 )                         // Playing with Potentiometer P1 you can control current PWM duty cycle
                                        // For visual result, look at LED PC1
    {

      uint8_t cur_duty_byte;

      // Read 10 - bit ADC value and set newly acquired 8 - bit PWM duty
      adc_rd = ADC_Read(1) & 0x0000FFFF;
      current_duty = adc_rd / 4 ;
      cur_duty_byte = LoWord(current_duty);
      PWM2_Set_Duty(cur_duty_byte);          // Set newly acquired duty
      cur_duty_byte = cur_duty_byte * 0.39;  // 100 / 256
      ByteToStr(cur_duty_byte, txt);
      Lcd_Out(2, 11, txt);
      Delay_ms( 20 );
     }


  }